import { ContentImage } from '../content';
import { EventMode } from '../event-mode.type';
export interface LabModelBase {
    id: string;
    _hid: string;
    _url: string;
}
export interface LabNews extends LabModelBase {
    authorIds: string[];
    timestamp: number;
    title: string;
    topics: string[];
    thumbnail: ContentImage;
    likes: number;
}
export interface LabEvent extends LabModelBase {
    startAt: number;
    endAt: number;
    title: string;
    summary: string;
    mode: EventMode;
    series: string;
    topics: string[];
    thumbnail: ContentImage;
    downloads: {
        uri: string;
        filename: string;
    }[];
    likes: number;
    attendees: number;
}
export interface LabHackschoolCourse extends LabModelBase {
    title: string;
    summary: string;
    timestamp: number;
    thumbnail: ContentImage;
    topics: string[];
    chapterGroups: {
        title: string;
        summary: string;
        chapters: {
            id: string;
            _hid: string;
            title: string;
            estimatedTime: number;
        }[];
    }[];
    estimatedTime: number;
}
export interface LabHackschoolThread extends LabModelBase {
    authorId: string;
    title: string;
    tags: string[];
    impressions: number;
    createdAt: string;
    updatedAt: string;
}
export interface LabHackschoolDoc extends LabModelBase {
    authorId: string;
    title: string;
    summary: string;
    topics: string[];
    impressions: number;
    likes: number;
    createdAt: string;
    updatedAt: string;
}
export interface LabDemo extends LabModelBase {
    title: string;
    tagline: string;
    favicon: string;
    href?: string;
    color: string;
    contactId: string;
    likes: number;
}
export interface LabBlip extends LabModelBase {
    title: string;
    category: string;
    logo: ContentImage;
    links: string[];
    history: {
        description: string;
        state: string;
        timestamp: number;
    }[];
    submitterId?: string;
    likes: number;
}
export interface LabRadar extends LabModelBase {
    timestamp: number;
    examine: string[];
    observe: string[];
    pilot: string[];
    utilize: string[];
    credits: string[];
    blips: Record<'examine' | 'observe' | 'pilot' | 'utilize', Partial<Record<'infrastructure' | 'tools' | 'techniques' | 'frameworks', {
        id: string;
        status: string;
    }[]>>>;
    total: number;
    likes: number;
    title: string;
}
export interface LabPodcast extends LabModelBase {
    audio: string;
    podcasterIds: string[];
    timestamp: number;
    title: string;
    summary: string;
    topics: string[];
    cover: ContentImage;
    played: number;
    likes: number;
}
export interface LabBook extends LabModelBase {
    title: string;
    summary: string;
    genre: string;
    publisher: string;
    releasedAt: number;
    author: string;
    topics: string[];
    timestamp: number;
    cover: ContentImage;
    submitterId: string;
    likes: number;
    readingListSize: number;
}
export interface LabMember extends LabModelBase {
    name: string;
    role: string;
    avatar?: string;
    member_since: number;
    member_until?: number;
    highlights: {
        year: number;
        highlight: string;
    }[];
    qna: {
        q: string;
        a: string;
    }[];
    links: {
        href: string;
        type: string;
    }[];
    active: boolean;
}
export interface LabNewsletter extends LabModelBase {
    timestamp: number;
    summary: string;
    topics: string[];
    title: string;
    likes: number;
}
export interface LabProject extends LabModelBase {
    title: string;
    likes: number;
}
